@@ -69,6 +69,17 @@ char *terminal_settings_list_dup_default_child (TerminalSettingsList *list);
 void terminal_settings_list_set_default_child (TerminalSettingsList *list,
                                                const char *uuid);
 
+typedef void (* TerminalSettingsListForeachFunc) (TerminalSettingsList *list,
+                                                  const char *uuid,
+                                                  GSettings *child,
+                                                  gpointer user_data);
+
+void terminal_settings_list_foreach_child (TerminalSettingsList *list,
+                                           TerminalSettingsListForeachFunc callback,
+                                           gpointer user_data);
+
+guint terminal_settings_list_get_n_children (TerminalSettingsList *list);
+
 gboolean terminal_settings_list_valid_uuid (const char *str);
 
 G_END_DECLS
